@@ -26,7 +26,8 @@
 #endif
 
 #include "others.h"
+
 int cli_ooxml_filetype(cli_ctx *, fmap_t *);
-int cli_process_ooxml(cli_ctx *);
+int cli_process_ooxml(cli_ctx *, int);
 
 #endif
